@@ -81,9 +81,12 @@ static void gx_regler_adjustment_notified(GObject *gobject, GParamSpec *pspec);
 static void gx_regler_move_slider(GtkRange *range, GtkScrollType scroll);
 
 G_DEFINE_ABSTRACT_TYPE_WITH_CODE(GxRegler, gx_regler, GTK_TYPE_RANGE,
+								 G_ADD_PRIVATE(GxRegler)
                                  G_IMPLEMENT_INTERFACE(GX_TYPE_CONTROL_PARAMETER,
                                                        gx_control_parameter_interface_init));
 
+#define GX_REGLER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GX_TYPE_REGLER, GxReglerPrivate))
+
 static void gx_regler_value_changed(GtkRange *range)
 {
 	gtk_widget_queue_draw(GTK_WIDGET(range));
@@ -549,8 +552,6 @@ static void gx_regler_class_init(GxReglerClass *klass)
 
 	add_slider_binding (binding_set, GDK_KP_End, (GdkModifierType)0,
 	                    GTK_SCROLL_END);
-
-	g_type_class_add_private(klass, sizeof (GxReglerPrivate));
 }
 
 
@@ -1334,7 +1335,7 @@ static void gx_regler_adjustment_notified(GObject *gobject, GParamSpec *pspec)
 
 static void gx_regler_init(GxRegler *regler)
 {
-	regler->priv = G_TYPE_INSTANCE_GET_PRIVATE (regler, GX_TYPE_REGLER, GxReglerPrivate);
+	regler->priv = GX_REGLER_GET_PRIVATE (regler);
 	GTK_RANGE(regler)->round_digits = -1;
 	regler->value_position = GTK_POS_BOTTOM;
 	regler->show_value = TRUE;
