@@ -23,11 +23,6 @@
 #pragma once
 
 
-#include <lilv/lilv.h>
-#include "lv2/lv2plug.in/ns/ext/presets/presets.h"
-#include "lv2/lv2plug.in/ns/ext/state/state.h"
-#include "lv2/lv2plug.in/ns/ext/urid/urid.h"
-
 namespace gx_jack { class GxJack; }
 
 namespace gx_engine {
@@ -610,6 +605,35 @@ public:
     ~PreampConvolver();
 };
 
+#include "faust/preamp_impulse_former_st.h"
+
+class PreampStereoConvolver: public FixedBaseConvolver {
+private:
+    int current_pre;
+    float level;
+    int preamp;
+    float bass;
+    float treble;
+    float sum;
+    value_pair *pre_names;
+    preamp_impulse_former_st::Dsp impf;
+    gx_resample::FixedRateResampler smp;
+    gx_resample::FixedRateResampler smps;
+    static void run_pre_conf(int count, float *input, float *input1, float *output, float *output1, PluginDef*);
+    static int register_pre(const ParamReg& reg);
+    bool do_update();
+    virtual void check_update();
+    virtual bool start(bool force = false);
+    bool preamp_changed() { return current_pre != preamp; }
+    void update_preamp() { current_pre = preamp; }
+    bool sum_changed() { return fabs(sum - (level + bass + treble)) > 0.01; }
+    void update_sum() { sum = level + bass + treble; }
+public:
+    PreampStereoConvolver(EngineControl& engine, sigc::slot<void> sync,
+       gx_resample::BufferResampler& resamp);
+    ~PreampStereoConvolver();
+};
+
 /****************************************************************
  ** class ContrastConvolver
  */
@@ -635,6 +659,41 @@ public:
     ~ContrastConvolver();
 };
 
+/****************************************************************
+ ** class LV2Features
+ */
+
+class LV2Features {
+private:
+
+    static LV2_Options_Option gx_options[2];
+    static LV2_Feature gx_options_feature;
+
+    static LV2_URID lv2_urid_map(LV2_URID_Map_Handle, const char* const uri_);
+    static LV2_Feature gx_urid_map_feature;
+    
+    static uint32_t lv2_uri_to_id(LV2_URI_Map_Callback_Data handle, const char*, const char* uri);
+    static LV2_URI_Map_Feature gx_uri_map;
+    static LV2_Feature gx_uri_map_feature;
+    
+    static const char* lv2_urid_unmap(LV2_URID_Unmap_Handle, const LV2_URID urid);
+    static LV2_Feature gx_urid_unmap_feature;
+    LV2Features() {};
+
+public:
+    static LV2Features& getInstance()
+        {
+            static LV2Features  instance;
+            return instance;
+        }
+    static LV2_Feature* gx_features[];
+    static LV2_URID_Map gx_urid_map;
+    static LV2_URID_Unmap gx_urid_unmap;
+
+    LV2Features(LV2Features const&)     = delete;
+    void operator=(LV2Features const&)  = delete;
+
+};
 
 /****************************************************************
  ** class LadspaLoader
@@ -723,9 +782,40 @@ public:
 
 
 /****************************************************************
- ** class LiveLooper
+ ** class Directout
  */
 
+class Directout: public PluginDef {
+public:
+    float* outdata;
+private:
+	int fSamplingFreq;
+    int 	bsize;
+    bool fdfill;
+    EngineControl&  engine;
+    sigc::slot<void> sync;
+    void mem_alloc();
+    void mem_free();
+    void init(unsigned int samplingFreq);
+    void compute(int count,  float *input0, float *input1, float *output0, float *output1);
+    void change_buffersize(unsigned int size);
+
+    static void init_static(unsigned int samplingFreq, PluginDef*);
+    static void compute_static(int count, float *input0, float *input1, float *output0, float *output1, PluginDef*);
+public:
+    bool   mem_allocated;
+    float* get_buffer() {return outdata;};
+    void set_data(bool dfill);
+    Plugin plugin;
+    static Plugin directoutput;
+    Directout( EngineControl& engine, sigc::slot<void> sync);
+    ~Directout();
+};
+
+
+/****************************************************************
+ ** class LiveLooper
+ */
 
 class LiveLooper: public PluginDef {
 	
@@ -767,6 +857,14 @@ private:
 	float 	load2;
 	float 	load3;
 	float 	load4;
+	float 	od1;
+	float 	od2;
+	float 	od3;
+	float 	od4;
+	float 	fod1;
+	float 	fod2;
+	float 	fod3;
+	float 	fod4;
 	float 	record1;
 	int 	iVec0[2];
 	int 	IOTA1;
@@ -835,10 +933,16 @@ private:
 	float 	playh4;
 	float 	gain4;
 	float 	play_all;
+    float 	dout;
+    float* outbuffer;
 	bool save1;
 	bool save2;
 	bool save3;
 	bool save4;
+	bool first1;
+	bool first2;
+	bool first3;
+	bool first4;
 	bool RP1;
 	bool RP2;
 	bool RP3;
@@ -856,6 +960,7 @@ private:
     sigc::slot<void> sync;
 	volatile int ready;
     FileResampler smp;
+    Directout* d;
 
     int do_resample(int inrate, int insize, float *input, int maxsize);
     int do_mono(int c, int f, float *oIn, float *tape, int n);
@@ -966,6 +1071,22 @@ public:
 
 #include "faust/drumseq.h"
 
+class Drumout {
+private:
+    static float* set;
+    static bool mb;
+    static float* data;
+    static Plugin input_drum;
+    static void outputdrum_compute(int count, float *input0, float *input1, float *output0, float *output1, PluginDef*);
+public:
+    static void set_plugin(Plugin p);
+    static void set_data(float* mode, bool ready, float* buf);
+    static Plugin output_drum;
+    static PluginDef outputdrum;
+    Drumout();
+};
+
+
 class DrumSequencer: public PluginDef {
 private:
 	int fSamplingFreq;
@@ -979,6 +1100,7 @@ private:
 
 	int 	counter;
 	int 	seq_size;
+    int 	bsize;
 	FAUSTFLOAT 	step;
 	FAUSTFLOAT 	step_orig;
 	FAUSTFLOAT 	fSlow1;
@@ -990,6 +1112,7 @@ private:
 	FAUSTFLOAT 	fSlow16;
 	FAUSTFLOAT 	fSlow18;
 	FAUSTFLOAT 	fSlow20;
+	FAUSTFLOAT 	fSlow22;
 	std::vector<int> Vectom;
 	std::vector<int> Vectom1;
 	std::vector<int> Vectom2;
@@ -997,6 +1120,11 @@ private:
 	std::vector<int> Vecsnare;
 	std::vector<int> Vechat;
 
+    EngineControl&  engine;
+	bool            mem_allocated;
+    sigc::slot<void> sync;
+	volatile bool ready;
+    float *outdata;
     ParamMap& param;
     GxSeqSettings tomset;
     SeqParameter *tomp;
@@ -1011,8 +1139,11 @@ private:
     GxSeqSettings kickset;
     SeqParameter *kickp;
 
+    void mem_alloc();
+	void mem_free();
 	void init(unsigned int samplingFreq);
 	void compute(int count, FAUSTFLOAT *input0, FAUSTFLOAT *output0);
+    void change_buffersize(unsigned int size);
 	int register_par(const ParamReg& reg);
 
 	int min_seq_size();
@@ -1029,7 +1160,7 @@ private:
 	static void del_instance(PluginDef *p);
 public:
     Plugin plugin;
-	DrumSequencer(ParamMap& param_);
+	DrumSequencer(ParamMap& param_, EngineControl& engine, sigc::slot<void> sync);
 	~DrumSequencer();
 };
 
