@@ -8,6 +8,57 @@ from models import *
 import dk_simulator, dk_lib
 from numpy.fft import fftfreq
 
+
+Tubes = {
+    "12ax7" : dict(mu = 100.0, Ex = 1.4, Kp = 600.0, Kvb = 300.0, Kg1 = 1060.0, Gco = -0.2, Gcf = 1e-5),
+    "12au7" : dict(mu = 21.5, Ex = 1.3, Kp = 84.0, Kvb = 300.0, Kg1 = 1180.0, Gco = 0, Gcf = 12e-5),
+    "12au7a": dict(mu = 19.41, Ex = 1.226, Kp = 104.87, Kvb = 300.0, Kg1 = 1233.8, Gco = 0, Gcf = 9e-5),
+    "12at7" : dict(mu = 60.0, Ex = 1.35, Kp = 300.0, Kvb = 300.0, Kg1 = 460.0, Gco = -0.5, Gcf = 12e-5),
+    "12ay7" : dict(mu = 44.16, Ex = 1.11, Kp = 409.96, Kvb = 300.0, Kg1 = 1192.4, Gco = -0.5, Gcf = 12e-5),
+    "7025"  : dict(mu = 102.5, Ex = 1.41, Kp = 813.8, Kvb = 44.9, Kg1 = 1598.8, Gco = -0.2, Gcf = 1e-5),
+    "EL34"  : dict(mu = 12.3, Ex = 1.17, Kp = 61.1, Kvb = 29.9, Kg1 = 353.9, Kg2 = 4500.0, Gco = -0.2, Gcf = 1e-5),
+    "EL84"  : dict(mu = 21.3, Ex = 1.24, Kp = 111.1, Kvb = 17.9, Kg1 = 401.7, Kg2 = 4500.0, Gco = -0.2, Gcf = 1e-5),
+    "EF86"  : dict(mu = 34.9, Ex = 1.35, Kp = 222.06, Kvb = 4.7, Kg1 = 2648.1, Kg2 = 4627, Gco = -0.2, Gcf = 1e-5),
+    "6L6"   : dict(mu = 8.7, Ex = 1.35, Kp = 48.0, Kvb = 12.0, Kg1 = 1460.0, Kg2 = 4500.0, Gco = -0.2, Gcf = 1e-5),
+    "6L6CG" : dict(mu = 8.7, Ex = 1.35, Kp = 48.0, Kvb = 12.0, Kg1 = 1460.0, Kg2 = 4500.0, Gco = -0.2, Gcf = 1e-5),
+    "6V6"   : dict(mu = 10.7, Ex = 1.31, Kp = 41.16, Kvb = 12.7, Kg1 = 1672.0, Kg2 = 4500.0, Gco = -0.2, Gcf = 1e-5),
+    "6V6GT" : dict(mu = 12.67, Ex = 1.198, Kp = 38.07, Kvb = 30.2, Kg1 = 915.0, Kg2 = 4500.0, Gco = 0.0, Gcf = 12e-5),
+    "6AU6"  : dict(mu = 36.65, Ex = 1.376, Kp = 215.42, Kvb = 15.0, Kg1 = 1129.4, Kg2 = 1059, Gco = -0.2, Gcf = 1e-5),
+    }
+
+# values taken from Datasheets, Vt is the termal Voltage (const)
+
+Transistors = {
+    "2N5088" : dict(Vt=26e-3,Is=20.3e-15,Bf=1430,Br=4), #npn
+    "2N5089" : dict(Vt=26e-3,Is=5.911e-15,Bf=1434,Br=1.262), #npn
+    "2N3904" : dict(Vt=26e-3,Is=1e-14,Bf=300,Br=4), #npn
+    "2N4401" : dict(Vt=26e-3,Is=9.09e-15,Bf=300,Br=4), #npn
+    "BD139"  : dict(Vt=26e-3,Is=2.3985e-13,Bf=244.9,Br=78.11), #npn
+    "BC108"  : dict(Vt=26e-3,Is=1.8e-14,Bf=400,Br=35.5), #npn
+    "BC546B" : dict(Vt=26e-3,Is=2.39e-14,Bf=294.3,Br=7.946), #npn
+    "AC128"  : dict(Vt=26e-3,Is=5e-6,Bf=90,Br=5),  #pnp
+    "MPSA18" : dict(Vt=26e-3,Is=20.3e-15,Bf=1430,Br=4),  #npn
+    }
+
+# values taken from Datasheets, mUt is now Vt = the termal Voltage (const)
+# N is the Emission coefficient
+
+Diodes = {
+    "D237A"    : dict(Is=31.69e-12, mUt=26e-3, N=1.0),
+    "1N4001"   : dict(Is=29.5e-9, mUt=26e-3, N=1.984),
+    "1N4148"   : dict(Is=2.52e-9, mUt=26e-3, N=1.752),
+    "1N34A"    : dict(Is=2.6e-6, mUt=26e-3, N=1.6),
+    "1N4148"   : dict(Is=2.52e-9, mUt=26e-3, N=1.752),
+    "1N914"    : dict(Is=2.52e-9, mUt=26e-3, N=1.752),
+    "LedRed"   : dict(Is=93.2e-12, mUt=26e-3, N=3.73),
+    "LedWHITE" : dict(Is=0.27e-9, mUt=26e-3, N=6.79),
+    "D311A"    : dict(Is=8e-6, mUt=26e-3, N=1.483),
+    "AA112"    : dict(Is=1.2e-6, mUt=26e-3, N=1.4),
+    "OA90-G"   : dict(Is=54.12e-6, mUt=26e-3, N=4.209),
+    "OA90-M"   : dict(Is=120.5e-6, mUt=26e-3, N=7.405),
+    }
+
+
 class Test(object):
     FS = 96000
     max_error = 1e-7
@@ -415,7 +466,6 @@ class Tonestack_test(Test):
         pl.plot(x, y)
         self.finish_plot(p.out_labels)
 
-
 class Diode_test(Test):
     S = ((D(), "V+", GND),
          (IN, "V+"),
@@ -723,7 +773,7 @@ class WahWah_test(Test): # wah-wah
             y = self.spectrum_signal(p, magnitude=1e-4)
             if n is None:
                 n = dk_lib.pow2roundup(len(y))
-                cut = slice(n*20.0/self.FS, n*10000.0/self.FS)
+                cut = slice(n*20//int(self.FS), n*10000//int(self.FS))
                 w = fftfreq(n,1.0/self.FS)[cut]
             pl.semilogx(w, spec(y))
             if isinstance(lbl, basestring):
@@ -761,7 +811,6 @@ class WahWah_ss(WahWah_test): # wah-wah small signal model
         else:
             return "Fail"
 
-
 class Transistor_test(Test): # transitor test
     S = ((R(1), "Vcc", "Vc"),
          (R(2), "Ve", GND),
@@ -835,17 +884,6 @@ class Triode1_test(Test): # triode test
         pl.plot(self.get_samples(self.sig), -self.result, "rx")
         self.finish_plot(p.out_labels)
 
-Tubes = {
-    "12ax7": dict(mu = 100.0, Ex = 1.4, Kp = 600.0, Kvb = 300.0, Kg1 = 1060.0, Gco = -0.2, Gcf = 1e-5),
-    "12au7": dict(mu = 21.5, Ex = 1.3, Kp = 84.0, Kvb = 300.0, Kg1 = 1180.0, Gco = 0, Gcf = 12e-5),
-    "12at7": dict(mu = 60.0, Ex = 1.35, Kp = 300.0, Kvb = 300.0, Kg1 = 460.0, Gco = -0.5, Gcf = 12e-5),
-    "12ay7": dict(mu = 44.16, Ex = 1.11, Kp = 409.96, Kvb = 300.0, Kg1 = 1192.4, Gco = -0.5, Gcf = 12e-5),
-    "EL34": dict(mu = 12.3, Ex = 1.17, Kp = 61.1, Kvb = 29.9, Kg1 = 353.9, Kg2 = 4500.0, Gco = -0.2, Gcf = 1e-5),
-    "6V6": dict(mu = 8.7, Ex = 1.35, Kp = 48.0, Kvb = 12.0, Kg1 = 1460.0, Kg2 = 4500.0, Gco = -0.2, Gcf = 1e-5),
-    "EL84": dict(mu = 21.3, Ex = 1.24, Kp = 111.1, Kvb = 17.9, Kg1 = 401.7, Kg2 = 4500.0, Gco = -0.2, Gcf = 1e-5),
-    "6L6": dict(mu = 8.7, Ex = 1.35, Kp = 48.0, Kvb = 12.0, Kg1 = 1460.0, Kg2 = 4500.0, Gco = -0.2, Gcf = 1e-5),
-    }
-
 class Triode2_test(Test): # triode test 2
     S = ((Triode(), "Vg", "Va", "Vk"),
          (R("g"), "Vi", "Vg"),
@@ -894,7 +932,6 @@ class Triode2_test(Test): # triode test 2
         pl.plot(self.sig, y)
         self.finish_plot(p.out_labels, loc="upper center", timeline=self.sig)
 
-
 class Preamp_test(Test):
     S = ((P(6), GND, 8, 9),
          #(R(61), 8, 9),
@@ -990,3 +1027,292 @@ class Preamp_test(Test):
         y = p(self.signal())
         pl.plot(x, y)
         self.finish_plot(p.out_labels, timeline=x)
+
+class Pentode_test(Test): # catode follower test 2
+    S = ((R(21), GND, 'out',),
+         (R(41), 'u5', 'u3',),
+         (C(11), 'out', 'u5',),
+         (V('cc'), 'Vcc',),
+         (Pentode(1), 'u4', 'Vcc', 'Vcc', 'u5',),
+         (C(1), 'u4', 'in',),
+         (R(1), 'u3', 'u4',),
+         (R(2), GND, 'u3',),
+         (IN, 'in', ),
+         (OUT, 'in', 'out'),
+         )
+    V = {C(1): 330.e-9,
+         C(11): 1.e-6,
+         Pentode(1): Tubes['EL34'],
+         R(1): 47.e3,
+         R(2): 20.e3,
+         R(21): 300.e3,
+         R(41): 1.e3,
+         V('cc'): 135.,
+         #"OP": [0, 135],
+         }
+
+    result = np.array([[  9.19061293e-15,  -2.03062627e-06],
+           [  4.92901172e-01,   4.36210348e-01],
+           [  1.71693967e-01,   1.44529472e-01],
+           [ -4.34100536e-01,  -3.94027980e-01],
+           [ -3.22507769e-01,  -2.88672770e-01],
+           [  3.22507769e-01,   2.87031653e-01],
+           [  4.34100536e-01,   3.80963052e-01],
+           [ -1.71693967e-01,  -1.61677810e-01],
+           [ -4.92901172e-01,  -4.43227157e-01],
+           [  8.94571941e-15,   4.56005926e-04]])
+
+
+    def signal(self):
+        return 0.5*self.sine_signal(200.0)
+
+    def plot(self, p):
+        x = self.timeline()
+        y = p(self.signal())
+        pl.plot(x, y)
+        #self.print_data(y, "\nresult = np.")
+        self.finish_plot(p.out_labels, timeline=x)
+
+class Pentode2_test(Test): # push_pull test
+    S = ((R(44), 'u13', 'in',),
+         (C(5), 'u13', GND,),
+         (P(2), GND, 'u11', 'u14',),
+         (C(4), 'out', 'u14',),
+         (R(22), GND, 'u11',),
+         (C(3), 'u5', 'u13',),
+         (V('cc2'), 'u9',),
+         (V('cc1'), 'u12',),
+         (Trans_L('Trans'), 'u8', 'u12', 'u12', 'u10', 'u11', GND,),
+         (Pentode(2), 'u7', 'u9', 'u10', 'u4',),
+         (Pentode(1), 'u6', 'u9', 'u8', 'u4',),
+         (C(1), 'u4', GND,),
+         (R(8), 'u7', 'u3',),
+         (R(4), 'u6', 'u5',),
+         (R(1), GND, 'u5',),
+         (R(3), 'u4', GND,),
+         (R(2), 'u3', GND,),
+         (IN, 'in',),
+         (OUT, 'out','in',),
+         )
+    V = {C(1): 25.e-6,
+         C(3): 0.1e-6,
+         C(4): 0.1e-6,
+         C(5): 88.5e-9,
+         P(2): dict(value=1000.e3, var='Volume'),
+         Pentode(1): Tubes['EL34'],
+         Pentode(2): Tubes['EL34'],
+         R(1): 220.e3,
+         R(2): 220.e3,
+         R(22): 220.e3,
+         R(3): 250.e3,
+         R(4): 1.5e3,
+         R(44): 150.,
+         R(8): 1.5e3,
+         Trans_L('Trans'): {'windings': [1000.0, 1000.0, 1000.0], 'R': 358.0, 'nw': 3.0},
+         V('cc1'): 360.,
+         V('cc2'): 320.,
+         "OP": [0],
+         "POT": dict(Pv=0.5),
+         }
+    
+    result = np.array([[  0.00000000e+00,   0.00000000e+00],
+           [ -3.93729973e-01,   2.16778685e-01],
+           [  5.19211387e-01,  -2.15958590e-01],
+           [ -1.90796327e-02,   8.18547952e-04],
+           [ -4.13219038e-01,   2.16369797e-01],
+           [  5.03192950e-01,  -2.16369797e-01],
+           [ -2.98470505e-02,  -8.18547952e-04],
+           [ -4.24291910e-01,   2.15958590e-01],
+           [  4.94164949e-01,  -2.16778685e-01],
+           [ -3.98751574e-02,  -1.83697020e-16]])
+
+    timespan = 0.02
+
+    def signal(self):
+        self.sig = np.linspace(0, 24.0, 200)
+        a = self.op_signal(samples=len(self.sig))
+        a[:,0] += self.sig
+        return a
+
+    # def signal(self):
+    #     return 0.25*self.sine_signal(150.0)
+
+    def plot(self, p):
+        x = self.timeline()
+        y = p(self.signal())
+       # pl.plot(x, y)
+        pl.plot(self.sig, -y/160.0)
+        self.finish_plot(p.out_labels, timeline=x)
+
+    def plot_spectrum(self, p, plot_variable):
+        varlist = []
+        if plot_variable:
+            if plot_variable not in p.pot_list:
+                raise ArgumentError("variable %s not found" % plot_variable)
+            ##hack
+            for k, t in self.V.items():
+                if isinstance(k, P):
+                    if not isinstance(t, dict):
+                        t = dict(value=t)
+                    var = t.get('var')
+                    if var is None:
+                        var = str(k)+'v'
+                    if var == plot_variable:
+                        break
+            loga = t.get('a', 0)
+            inv = t.get('inv', 0)
+            for i in range(5):
+                pot = i/4
+                lbl = "%s" % pot
+                if inv:
+                    pot = 1 - pot
+                if loga:
+                    pot = (math.exp(loga * pot) - 1) / (math.exp(loga) - 1)
+                varlist.append((plot_variable, pot, lbl))
+        else:
+            varlist.append((None, None, p.out_labels))
+        n = None
+        cut = None
+        def spec(y):
+            s = 20*np.log10(abs(np.fft.fft(y,n,axis=0)[cut]))
+            return np.where(s > -80, s, np.nan)
+        labels = []
+        for var, val, lbl in varlist:
+            if var is not None:
+                p.set_variable(var, val)
+            y = self.spectrum_signal(p, magnitude=1e-4)
+            if n is None:
+                n = dk_lib.pow2roundup(len(y))
+                cut = slice(n*20//int(self.FS), n*10000//int(self.FS))
+                w = fftfreq(n,1.0/self.FS)[cut]
+            pl.semilogx(w, spec(y),label=plot_variable)
+            pl.xlabel('Frequency')
+            pl.ylabel('Magnitude ')
+            if plot_variable:
+                pl.title(plot_variable)
+            if isinstance(lbl, basestring):
+                labels.append(lbl)
+            else:
+                labels.extend(lbl)
+        ax = pl.gca()
+        ax.grid()
+        ax.yaxis.set_major_formatter(pl.FormatStrFormatter('%d dB'))
+        ax.xaxis.set_major_formatter(pl.FormatStrFormatter('%d Hz'))
+        self.finish_plot(labels, loc='upper left')
+
+class Fuzz_test(Test): # fuzz face fuller mods test
+    S = ((R(5), GND, 'u9',),
+         (R(7), 'u12', '+9V',),
+         (P(1), 'in', 'u6', 'in',),
+         (P(2), 'u12', 'u2', 'u12',),
+         (V('cc'), '+9V',),
+         (P(3), 'u5', GND, 'u7',),
+         (P(4), 'u8', 'u9', 'out',),
+         (T(2), 'u3', 'u1', 'u5',),
+         (T(1), 'u1', 'u4', GND,),
+         (C(4), 'u8', 'u2',),
+         (C(5), 'u7', GND,),
+         (C(1), 'u6', 'u4',),
+         (R(3), 'u5', 'u4',),
+         (R(4), 'u3', 'u2',),
+         (R(6), 'u1', '+9V',),
+         (IN, 'in',),
+         (OUT, 'out','in',),
+         )
+    V = {C(1): 2.2e-6,
+         C(4): 0.01e-6,
+         C(5): 22.e-6,
+         P(1): dict(value=50.e3, var='Input'),
+         P(2): dict(value=1.e3, var='Drive', inv=1),
+         P(3): dict(value=1.e3, var='Fuzz', inv=1),
+         P(4): dict(value=400.e3, var='Volume', inv=1),
+         R(3): 100.e3,
+         R(4): 8.2e3,
+         R(5): 100.e3,
+         R(6): 33.e3,
+         R(7): 470.,
+         T(1): dict(Vt=26e-3, Is=20.3e-15, Bf=1430, Br=4),
+         T(2): dict(Vt=26e-3, Is=20.3e-15, Bf=1430, Br=4),
+         V('cc'): 9.,
+         "OP": [0],
+         "POT": dict(Pv=0.5),
+         }
+    
+    result = np.array([[  2.30300223e-11,   0.00000000e+00],
+           [  2.91297798e-01,   4.92901172e-01],
+           [  2.33677108e-01,   1.71693967e-01],
+           [ -2.42940849e-01,  -4.34100536e-01],
+           [ -1.93428827e-01,  -3.22507769e-01],
+           [  3.10440347e-01,   3.22507769e-01],
+           [  2.49033130e-01,   4.34100536e-01],
+           [ -2.80840688e-01,  -1.71693967e-01],
+           [ -2.23787640e-01,  -4.92901172e-01],
+           [ -9.69408910e-02,  -2.44929360e-16]])
+
+    #timespan = 0.5
+
+    def signal(self):
+        return 0.5*self.sine_signal(200.0)
+
+    def plot(self, p):
+        x = self.timeline()
+        y = p(self.signal())
+        pl.plot(x, y)
+        #self.print_data(y, "\nresult = np.")
+        self.finish_plot(p.out_labels, timeline=x)
+
+    def plot_spectrum(self, p, plot_variable):
+        varlist = []
+        if plot_variable:
+            if plot_variable not in p.pot_list:
+                raise ArgumentError("variable %s not found" % plot_variable)
+            ##hack
+            for k, t in self.V.items():
+                if isinstance(k, P):
+                    if not isinstance(t, dict):
+                        t = dict(value=t)
+                    var = t.get('var')
+                    if var is None:
+                        var = str(k)+'v'
+                    if var == plot_variable:
+                        break
+            loga = t.get('a', 0)
+            inv = t.get('inv', 0)
+            for i in range(5):
+                pot = i/4
+                lbl = "%s" % pot
+                if inv:
+                    pot = 1 - pot
+                if loga:
+                    pot = (math.exp(loga * pot) - 1) / (math.exp(loga) - 1)
+                varlist.append((plot_variable, pot, lbl))
+        else:
+            varlist.append((None, None, p.out_labels))
+        n = None
+        cut = None
+        def spec(y):
+            s = 20*np.log10(abs(np.fft.fft(y,n,axis=0)[cut]))
+            return np.where(s > -80, s, np.nan)
+        labels = []
+        for var, val, lbl in varlist:
+            if var is not None:
+                p.set_variable(var, val)
+            y = self.spectrum_signal(p, magnitude=1e-4)
+            if n is None:
+                n = dk_lib.pow2roundup(len(y))
+                cut = slice(n*20//int(self.FS), n*10000//int(self.FS))
+                w = fftfreq(n,1.0/self.FS)[cut]
+            pl.semilogx(w, spec(y),label=plot_variable)
+            pl.xlabel('Frequency')
+            pl.ylabel('Magnitude ')
+            if plot_variable:
+                pl.title(plot_variable)
+            if isinstance(lbl, basestring):
+                labels.append(lbl)
+            else:
+                labels.extend(lbl)
+        ax = pl.gca()
+        ax.grid()
+        ax.yaxis.set_major_formatter(pl.FormatStrFormatter('%d dB'))
+        ax.xaxis.set_major_formatter(pl.FormatStrFormatter('%d Hz'))
+        self.finish_plot(labels, loc='upper left')
